@@ -22,17 +22,14 @@ from typing import TYPE_CHECKING, TypeVar
 
 from airflow.models import Param
 from airflow.models.xcom_arg import XComArg
+from airflow.providers.common.compat.sdk import DAG
 
 if TYPE_CHECKING:
-    from airflow.sdk import DAG, BaseOperator
-    from airflow.sdk.definitions.mappedoperator import MappedOperator
+    from airflow.providers.common.compat.sdk import BaseOperator, MappedOperator
+    from airflow.providers.openlineage.utils.utils import AnyOperator
+    from airflow.serialization.serialized_objects import SerializedDAG
 
     T = TypeVar("T", bound=DAG | BaseOperator | MappedOperator)
-else:
-    try:
-        from airflow.sdk import DAG
-    except ImportError:
-        from airflow.models import DAG
 
 ENABLE_OL_PARAM_NAME = "_selective_enable_ol"
 ENABLE_OL_PARAM = Param(True, const=True)
@@ -76,7 +73,7 @@ def disable_lineage(obj: T) -> T:
     return obj
 
 
-def is_task_lineage_enabled(task: BaseOperator | MappedOperator) -> bool:
+def is_task_lineage_enabled(task: AnyOperator) -> bool:
     """Check if selective enable OpenLineage parameter is set to True on task level."""
     if task.params.get(ENABLE_OL_PARAM_NAME) is False:
         log.debug(
@@ -85,7 +82,7 @@ def is_task_lineage_enabled(task: BaseOperator | MappedOperator) -> bool:
     return task.params.get(ENABLE_OL_PARAM_NAME) is True
 
 
-def is_dag_lineage_enabled(dag: DAG) -> bool:
+def is_dag_lineage_enabled(dag: DAG | SerializedDAG) -> bool:
     """
     Check if DAG is selectively enabled to emit OpenLineage events.
 
